#[non_exhaustive]pub enum BootstrapError {
InvalidUrl(String, String),
InvalidTlsPolicy(String),
MalformedField(String, String),
MissingField(&'static str),
UnsupportedVersion(String),
InvalidTlsForHttp,
MissingUrlHost,
InvalidRecord(String),
Ipv4EndpointNotAllowed,
}Expand description
Errors returned when parsing and validating a Bootstrap record.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidUrl(String, String)
The provisioning endpoint is not a supported HTTP or HTTPS URL.
InvalidTlsPolicy(String)
The bootstrap record contains an unsupported t value.
MalformedField(String, String)
A bootstrap field does not have its required key=value form or order.
MissingField(&'static str)
A required bootstrap field is absent.
UnsupportedVersion(String)
The bootstrap record declares an unsupported protocol version.
InvalidTlsForHttp
Certificate validation was requested for an HTTP endpoint.
MissingUrlHost
The provisioning URL does not contain a host.
InvalidRecord(String)
The record contains fields beyond the three fields defined by HB46PP.
Ipv4EndpointNotAllowed
The provisioning endpoint uses an IPv4 address instead of IPv6.